@@ -24,17 +24,15 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 """
-from __future__ import absolute_import
-
 import re
 
-from .base import BasePlugin
-from .base import classproperty
-from .common.filetype import determine_file_type
-from .common.filetype import FileType
-from .common.filters import get_aho_corasick_helper
-from .common.filters import is_sequential_string
 from detect_secrets.core.potential_secret import PotentialSecret
+from detect_secrets.plugins.base import BasePlugin
+from detect_secrets.plugins.base import classproperty
+from detect_secrets.plugins.common.filetype import determine_file_type
+from detect_secrets.plugins.common.filetype import FileType
+from detect_secrets.plugins.common.filters import get_aho_corasick_helper
+from detect_secrets.plugins.common.filters import is_sequential_string
 
 
 # Note: All values here should be lowercase
@@ -218,7 +216,6 @@ FOLLOWED_BY_QUOTES_AND_SEMICOLON_REGEX = re.compile(
         denylist=DENYLIST_REGEX,
         nonWhitespace=OPTIONAL_NON_WHITESPACE,
         quote=QUOTE,
-        closing=CLOSING,
         whitespace=OPTIONAL_WHITESPACE,
         secret=SECRET,
     ),
@@ -302,14 +299,12 @@ class KeywordDetector(BasePlugin):
             and self.keyword_exclude.search(string)
         ):
             return output
-
         for identifier in self.secret_generator(
             string,
             filetype=determine_file_type(filename),
         ):
             if self.is_secret_false_positive(identifier):
                 continue
-
             secret = PotentialSecret(
                 self.secret_type,
                 filename,
@@ -334,17 +329,15 @@ class KeywordDetector(BasePlugin):
 
         for denylist_regex, group_number in denylist_regex_to_group.items():
             match = denylist_regex.search(lowered_string)
-            if not match:
-                continue
+            if match:
+                lowered_secret = match.group(group_number)
 
-            lowered_secret = match.group(group_number)
-
-            # ([^\s]+) guarantees lowered_secret is not ''
-            if not probably_false_positive(
-                lowered_secret,
-                filetype=filetype,
-            ):
-                yield lowered_secret
+                # ([^\s]+) guarantees lowered_secret is not ''
+                if not probably_false_positive(
+                    lowered_secret,
+                    filetype=filetype,
+                ):
+                    yield lowered_secret
 
 
 def probably_false_positive(lowered_secret, filetype):
